@@ -14,9 +14,9 @@ pub struct Command {
     #[clap(short, long)]
     pub path: Option<String>,
 
-    /// Whether to compile using the IR pipeline.
+    /// Whether to compile using the original (pre- IR) pipeline.
     #[clap(long)]
-    pub use_ir: bool,
+    pub use_orig_asm: bool,
 
     /// Only craft transaction and print it out.
     #[clap(long)]
@@ -89,7 +89,7 @@ pub struct Command {
 
 pub(crate) async fn exec(command: Command) -> Result<()> {
     match forc_run::run(command).await {
-        Err(e) => bail!(e.message),
+        Err(e) => bail!("{}", e),
         _ => Ok(()),
     }
 }
