@@ -1,4 +1,4 @@
-use crate::cli::BuildCommand;
+use crate::{cli::BuildCommand, utils::SWAY_GIT_TAG};
 use anyhow::{anyhow, bail, Result};
 use forc_pkg::{self as pkg, lock, Lock, Manifest};
 use forc_util::{default_output_directory, find_manifest_dir, lock_path};
@@ -12,7 +12,7 @@ pub fn build(command: BuildCommand) -> Result<pkg::Compiled> {
     let BuildCommand {
         path,
         binary_outfile,
-        use_ir,
+        use_orig_asm,
         debug_outfile,
         print_finalized_asm,
         print_intermediate_asm,
@@ -24,7 +24,7 @@ pub fn build(command: BuildCommand) -> Result<pkg::Compiled> {
     } = command;
 
     let config = pkg::BuildConfig {
-        use_ir,
+        use_orig_asm,
         print_ir,
         print_finalized_asm,
         print_intermediate_asm,
@@ -48,11 +48,11 @@ pub fn build(command: BuildCommand) -> Result<pkg::Compiled> {
             );
         }
     };
-    let manifest = Manifest::from_dir(&manifest_dir)?;
+    let manifest = Manifest::from_dir(&manifest_dir, SWAY_GIT_TAG)?;
     let lock_path = lock_path(&manifest_dir);
 
     // Load the build plan from the lock file.
-    let plan_result = pkg::BuildPlan::from_lock_file(&lock_path);
+    let plan_result = pkg::BuildPlan::from_lock_file(&lock_path, SWAY_GIT_TAG);
 
     // Retrieve the old lock file state so we can produce a diff.
     let old_lock = plan_result
@@ -62,13 +62,14 @@ pub fn build(command: BuildCommand) -> Result<pkg::Compiled> {
         .unwrap_or_default();
 
     // Validate the loaded build plan for the current manifest.
-    let plan_result = plan_result.and_then(|plan| plan.validate(&manifest).map(|_| plan));
+    let plan_result =
+        plan_result.and_then(|plan| plan.validate(&manifest, SWAY_GIT_TAG).map(|_| plan));
 
     // If necessary, construct a new build plan.
     let plan: pkg::BuildPlan = plan_result.or_else(|e| -> Result<pkg::BuildPlan> {
         println!("  Creating a new `Forc.lock` file");
         println!("    Cause: {}", e);
-        let plan = pkg::BuildPlan::new(&manifest_dir, offline)?;
+        let plan = pkg::BuildPlan::new(&manifest_dir, SWAY_GIT_TAG, offline)?;
         let lock = Lock::from_graph(plan.graph());
         let diff = lock.diff(&old_lock);
         lock::print_diff(&manifest.project.name, &diff);
@@ -80,7 +81,7 @@ pub fn build(command: BuildCommand) -> Result<pkg::Compiled> {
     })?;
 
     // Build it!
-    let (compiled, source_map) = pkg::build(&plan, &config)?;
+    let (compiled, source_map) = pkg::build(&plan, &config, SWAY_GIT_TAG)?;
 
     if let Some(outfile) = binary_outfile {
         fs::write(&outfile, &compiled.bytecode)?;
